@@ -8,8 +8,8 @@ from openapi_spec_validator.validation import openapi_v31_spec_validator
 
 __author__ = "Artur Maciag"
 __email__ = "maciag.artur@gmail.com"
-__version__ = "0.5.4"
-__url__ = "https://github.com/p1c2u/openapi-spec-validator"
+__version__ = "0.5.7"
+__url__ = "https://github.com/python-openapi/openapi-spec-validator"
 __license__ = "Apache License, Version 2.0"
 
 __all__ = [
